# Response Status Codes
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/response-status-codes#overview)
  * [Success Codes (2xx)](https://help.sap.com/docs/leanix/ea/response-status-codes#success-codes-\(2xx\))
  * [Client-Side Error Codes (4xx)](https://help.sap.com/docs/leanix/ea/response-status-codes#client-side-error-codes-\(4xx\))
  * [Server-Side Error Codes (5xx)](https://help.sap.com/docs/leanix/ea/response-status-codes#server-side-error-codes-\(5xx\))


Overview of HTTP response status codes in SAP LeanIX APIs.
